==> genshitjokes-2023.5.26.tar.gz: genshitjokes-2023.5.26/genshitjokes/原批历史与文化学/原批历史与文化学.md <==
# 原批历史与文化学

## 一.文化输出

### 1.忍冬纹  Honeysuckle Pattern

纹输菩萨！纹化输出！

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/忍冬纹1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/忍冬纹2.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/忍冬纹3.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/忍冬纹与生理结构.jpg)

### 2.如意纹   Ruyi Pattern

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/如意纹.jpg)

### 3.原神的英文是？ What's English name of "YuanShen"?

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/原神的英文是？.jpg)

出处：<a href="https://www.bilibili.com/video/BV1Na411k7GT?p=1&t=32" target="_blank">王刚和四伯自制80斤川味香肠，是美食文化的传承也是满满的幸福</a>  的评论区，往下翻，没删

该原批个人空间：<a href="https://space.bilibili.com/954799" target="_blank">nanisamaga</a>

### 4.雷霆的威光   Thunder

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/雷霆的威光.jpg)

### 5.信息战 Information War

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/信息战.jpg)


### 6.非遗   Not Heritage

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/非遗.jpg)

### 7.涩不是烧   SFW

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/涩不是烧.jpg)

### 8.举国玩原   100% Genshit Players

<a href="https://www.bilibili.com/video/BV17g4y1g7YP" target="_blank">BV17g4y1g7YP</a>

<a href="https://space.bilibili.com/1105429038" target="_blank">退役编辑雨上</a>

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/举国玩原.jpg)

### 9.文化胜利   Cultural Victory

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化胜利1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化胜利2.jpg)

## 二.原批历史学

### 1.野史   Wild History

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/野史.jpg)

### 2.最多3000年

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/最多3000年.jpg)

### 3.只有3700年

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/只有3700年.jpg)

### 4.凝光的传奇人生   Ningguang's Legendary Life

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/凝光的传奇人生.jpg)

### 5.辛亥革命   The Revolution of 1911

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/辛亥革命.jpg)

## 三.原批艺术学

### 1.正宗京剧 Authentic Beijing "OP"era

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/正宗京剧.jpg)

### 2.这是艺术   This Is Art

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/这是艺术.jpg)

### 3.艺术品   Artworks

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/艺术品1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/艺术品2.jpg)

<a href="https://api.xiaoheihe.cn/v3/bbs/app/api/web/share?link_id=100955954" target="_blank">原帖：这游戏的互动能做得再差点吗</a>

## 四.米氏剧情

### 1.四大悲剧  Four Tragedies

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/四大悲剧.jpg)

### 2.有深度   Depth

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/有深度.jpg)

### 3.在喷什么   Why Criticize

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/在喷什么.jpg)

### 4.超越刘慈欣   Beyond 647

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/超越刘慈欣.jpg)

## 五.IP

### 1.迪士尼   Disneyland

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/迪士尼.jpg)

## 六.

### 1.学习文化   Learn Culture

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/学习文化.jpg)

==> genshitjokes-2023.8.10.tar.gz: genshitjokes-2023.8.10/genshitjokes/原批历史与文化学/原批历史与文化学.md <==
# 原批历史与文化学

## 一.文化输出


### 1.原神的英文是？ What's English name of "YuanShen"?

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/原神的英文是？.jpg)

出处：<a href="https://www.bilibili.com/video/BV1Na411k7GT?p=1&t=32" target="_blank">王刚和四伯自制80斤川味香肠，是美食文化的传承也是满满的幸福</a>  的评论区，往下翻，没删

该原批个人空间：<a href="https://space.bilibili.com/954799" target="_blank">nanisamaga</a>

### 2.雷霆的威光   Thunder

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/雷霆的威光.jpg)

### 3.信息战 Information War

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/信息战.jpg)


### 4.非遗   Not Heritage

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/非遗.jpg)

### 5.涩不是烧   SFW

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/涩不是烧.jpg)

### 6.举国玩原   100% Genshit Players

<a href="https://www.bilibili.com/video/BV17g4y1g7YP" target="_blank">BV17g4y1g7YP</a>

<a href="https://space.bilibili.com/1105429038" target="_blank">退役编辑雨上</a>

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/举国玩原.jpg)

### 7.文化胜利   Cultural Victory

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/文化胜利1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/文化输出专区/文化胜利2.jpg)

### 8.中原节   CNOP Day

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/中元节.jpg)

### 9.央视认证   CCTV

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/央视认证.jpg)

## 二.原批历史学

### 1.野史   Wild History

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/野史.jpg)

### 2.最多3000年

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/最多3000年.jpg)

### 3.只有3700年

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/只有3700年.jpg)

### 4.凝光的传奇人生   Ningguang's Legendary Life

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/凝光的传奇人生.jpg)

### 5.辛亥革命   The Revolution of 1911

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/辛亥革命.jpg)

### 6.诸葛亮

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/三国演义.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批历史学/诸葛神棍.jpg)

## 三.原批艺术学

### 1.忍冬纹  Honeysuckle Pattern

纹输菩萨！纹化输出！

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/忍冬纹1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/忍冬纹2.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/忍冬纹3.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/忍冬纹与生理结构.jpg)

### 2.如意纹   Ruyi Pattern

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/如意纹.jpg)

### 3.正宗京剧 Authentic Beijing "OP"era

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/正宗京剧.jpg)

### 4.这是艺术   This Is Art

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/这是艺术.jpg)

### 5.艺术品   Artworks

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/艺术品1.jpg)

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/原批艺术学/艺术品2.jpg)

<a href="https://api.xiaoheihe.cn/v3/bbs/app/api/web/share?link_id=100955954" target="_blank">原帖：这游戏的互动能做得再差点吗</a>

## 四.米氏剧情

### 1.四大悲剧  Four Tragedies

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/四大悲剧.jpg)

### 2.四大名著   Four Novels

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/四大名著.jpg)

### 3.有深度   Depth

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/有深度.jpg)

### 4.在喷什么   Why Criticize

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/在喷什么.jpg)

### 5.超越刘慈欣   Beyond 647

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/超越刘慈欣.jpg)

### 6.顶级剧情   Story NO.1

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/米氏剧情/顶级剧情.jpg)

## 五.IP

### 1.迪士尼   Disneyland

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/迪士尼.jpg)

## 六.

### 1.学习文化   Learn Culture

![](https://github.com/DreamingCats/GenshitJokes/raw/main/genshitjokes/原批历史与文化学/学习文化.jpg)
